<?php
/**
 * The template for displaying archive pages.
 *
 * @link     https://codex.wordpress.org/Template_Hierarchy
 *
 * @package  Healsoul
 * @since    1.0
 */
get_header();

$style       = Healsoul::setting( 'archive_caregiver_style' );
$animation   = Healsoul::setting( 'archive_caregiver_animation' );
$form_title  = Healsoul::setting( "archive_caregiver_form_title" );
$button_text = Healsoul::setting( "archive_caregiver_button_text" );

$result_class = 'search-result';
$result_class .= " style-$style";
?>
<?php Healsoul_Templates::title_bar(); ?>
	<div id="page-content" class="page-content">
		<div class="container">
			<div class="row">

				<?php Healsoul_Templates::render_sidebar( 'left' ); ?>

				<div class="page-main-content">
					<h3 class="search-title"><?php echo esc_html( $form_title ); ?></h3>
					<div class="search-form">
						<form action="<?php echo get_post_type_archive_link( 'ic_caregiver' ); ?>" method="GET">
							<?php
							wp_dropdown_categories(
								array(
									'show_option_none' => esc_html__( 'Choose a location', 'healsoul' ),
									'taxonomy'         => 'ic_caregiver_location',
									'name'             => 'lc',
									'selected'         => ( isset( $_GET['lc'] ) ? $_GET['lc'] : 0 ),
								)
							);
							wp_dropdown_categories(
								array(
									'show_option_none' => esc_html__( 'Choose a service', 'healsoul' ),
									'taxonomy'         => 'ic_caregiver_service',
									'name'             => 'sv',
									'selected'         => ( isset( $_GET['sv'] ) ? $_GET['sv'] : 0 ),
								)
							);
							?>
							<button type="submit"><?php echo esc_html( $button_text ) ?></button>
						</form>
					</div>

					<div class="<?php echo esc_attr( $result_class ); ?>">
						<div class="row">
							<?php
							$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
							if ( isset( $_GET['lc'] ) || isset( $_GET['sv'] ) ) {
								$args = array(
									'post_type' => 'ic_caregiver',
									'paged'     => $paged,
									'tax_query' => array(
										'relation' => 'AND',
									),
								);
								if ( isset( $_GET['lc'] ) && ( $_GET['lc'] != '-1' ) ) {
									$args['tax_query'][] = array(
										'taxonomy' => 'ic_caregiver_location',
										'field'    => 'id',
										'terms'    => array( $_GET['lc'] ),
									);
								}
								if ( isset( $_GET['sv'] ) && ( $_GET['sv'] != '-1' ) ) {
									$args['tax_query'][] = array(
										'taxonomy' => 'ic_caregiver_service',
										'field'    => 'id',
										'terms'    => array( $_GET['sv'] ),
									);
								}
								$query = new WP_Query( $args );
								if ( $query->have_posts() ) {
									echo '<div class="result-count">' . sprintf( _n( 'Success! We have found %s matching your needs.', 'Success! We have found %s matching your needs.', $query->found_posts, 'healsoul' ), number_format_i18n( $query->found_posts ) ) . '</div>';
									while ( $query->have_posts() ) {
										$query->the_post();
										get_template_part( 'loop/caregiver/style', $style );
									}
									wp_reset_postdata();
									Healsoul_Templates::paging_nav( $query );
								} else {
									echo '<div class="result-count">' . esc_html( 'Success! We have found 0 matching your needs.', 'healsoul' ) . '</div>';
								}
							} else {
								if ( have_posts() ) {
									while ( have_posts() ) {
										the_post();
										get_template_part( 'loop/caregiver/style', $style );
									}
									Healsoul_Templates::paging_nav();
									wp_reset_postdata();
								}
							}
							?>
						</div>
					</div>
				</div>

				<?php Healsoul_Templates::render_sidebar( 'right' ); ?>

			</div>
		</div>
	</div>
<?php get_footer();
