<?php
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Enqueue scripts and styles.
 */
if ( ! class_exists( 'Healsoul_Enqueue' ) ) {
	class Healsoul_Enqueue {

		protected static $instance = null;

		public function __construct() {
			add_action( 'enqueue_block_editor_assets', array( $this, 'gutenberg' ) );
			add_action( 'wp_enqueue_scripts', array( $this, 'enqueue' ) );

			// Disable all contact form 7 scripts.
			add_filter( 'wpcf7_load_js', '__return_false' );
			add_filter( 'wpcf7_load_css', '__return_false' );

			// Re queue contact form 7 scripts when used.
			add_action( 'wp_enqueue_scripts', array( $this, 'requeue_wpcf7_scripts' ), 99 );
		}

		function requeue_wpcf7_scripts() {
			global $post;
			if ( is_a( $post, 'WP_Post' ) && ( has_shortcode( $post->post_content, 'contact-form-7' ) || has_shortcode( $post->post_content, 'tm_contact_form_7' ) || has_shortcode( $post->post_content, 'tm_contact_form_7_box' ) ) ) {
				if ( function_exists( 'wpcf7_enqueue_scripts' ) ) {
					wpcf7_enqueue_scripts();
				}

				if ( function_exists( 'wpcf7_enqueue_styles' ) ) {
					wpcf7_enqueue_styles();
				}
			}
		}

		public static function instance() {
			if ( null === self::$instance ) {
				self::$instance = new self();
			}

			return self::$instance;
		}

		function gutenberg() {
			wp_enqueue_style( 'gutenberg-google-font', 'https://fonts.googleapis.com/css?family=Poppins:400,400i,500,500i,600,600i,700,700i', null, null );
			wp_enqueue_style( 'gutenberg-editor', HEALSOUL_THEME_URI . '/gutenberg-style.css', null, null );
		}

		/**
		 * Enqueue scripts & styles.
		 *
		 * @access public
		 */
		public function enqueue() {
			$post_type = get_post_type();
			$min       = $this->get_min_suffix();

			// Remove font awesome from Visual Composer plugin.
			wp_deregister_style( 'font-awesome' );
			wp_dequeue_style( 'font-awesome' );

			wp_register_style( 'font-awesome', HEALSOUL_THEME_URI . '/assets/fonts/awesome/css/fontawesome-all.min.css', null, '6.2.0' );
			wp_register_style( 'font-awesome-v5', HEALSOUL_THEME_URI . '/assets/fonts/awesome/css/v5-font-face.min.css', null, '6.2.0' );


			// RTL custom style
			wp_register_style( 'healsoul-style-rtl-custom', HEALSOUL_THEME_URI . "/style-rtl-custom$min.css", [ 'healsoul-style' ], HEALSOUL_THEME_VERSION );

			wp_enqueue_style( 'font-flaticon', HEALSOUL_THEME_URI . '/assets/fonts/flaticon/font-flaticon.css', null, null );
			wp_enqueue_style( 'font-healsoul', HEALSOUL_THEME_URI . '/assets/fonts/healsoul/font-healsoul.css', null, null );
			wp_enqueue_style( 'font-icomoon', HEALSOUL_THEME_URI . '/assets/fonts/icomoon/font-icomoon.css', null, null );
			wp_enqueue_style( 'font-icomoon2', HEALSOUL_THEME_URI . '/assets/fonts/icomoon2/font-icomoon2.css', null, null );
			wp_register_style( 'font-ion', HEALSOUL_THEME_URI . '/assets/fonts/ion/font-ion.min.css', null, null );
			wp_register_style( 'font-icomoon', HEALSOUL_THEME_URI . '/assets/fonts/icomoon/font-icomoon.css', null, null );
			wp_register_style( 'font-linea', HEALSOUL_THEME_URI . '/assets/fonts/linea/font-linea.min.css', null, null );

			wp_register_style( 'spinkit', HEALSOUL_THEME_URI . '/assets/libs/spinkit/spinkit.css', null, null );

			wp_register_style( 'justified-gallery', HEALSOUL_THEME_URI . '/assets/libs/justified-gallery/justifiedGallery.min.css', null, '3.6.3' );
			wp_register_script( 'justified-gallery', HEALSOUL_THEME_URI . '/assets/libs/justified-gallery/jquery.justifiedGallery.min.js', array( 'jquery' ), '3.6.3', true );

			wp_register_script( 'picturefill', HEALSOUL_THEME_URI . '/assets/libs/picturefill/picturefill.min.js', array( 'jquery' ), null, true );
			wp_register_script( 'mousewheel', HEALSOUL_THEME_URI . "/assets/libs/mousewheel/jquery.mousewheel.js", array( 'jquery' ), HEALSOUL_THEME_VERSION, true );
			wp_enqueue_style( 'lightgallery', HEALSOUL_THEME_URI . '/assets/libs/light-gallery/css/lightgallery.min.css', null, '1.6.4' );
			wp_enqueue_script( 'lightgallery', HEALSOUL_THEME_URI . "/assets/libs/light-gallery/js/lightgallery-all.js", array(
				'jquery',
				'picturefill',
				'mousewheel',
			),                 null, true );

			wp_register_style( 'lightslider', HEALSOUL_THEME_URI . '/assets/libs/light-slider/css/lightslider.min.css', null, '1.1.6' );
			wp_register_script( 'lightslider', HEALSOUL_THEME_URI . "/assets/js/lightslider.js", array( 'jquery' ), '1.1.6', true );

			wp_register_style( 'swiper', HEALSOUL_THEME_URI . '/assets/libs/swiper/css/swiper.min.css', null, '4.0.3' );
			wp_register_script( 'swiper', HEALSOUL_THEME_URI . "/assets/libs/swiper/js/swiper.js", array( 'jquery' ), '4.0.3', true );

			// Fix VC waypoints.
			if ( ! wp_script_is( 'vc_waypoints', 'registered' ) ) {
				wp_register_script( 'vc_waypoints', HEALSOUL_THEME_URI . '/assets/libs/vc-waypoints/vc-waypoints.min.js', array( 'jquery' ), null, true );
			}

			// Register scripts
			wp_register_script( 'slimscroll', HEALSOUL_THEME_URI . '/assets/libs/slimscroll/jquery.slimscroll.min.js', array( 'jquery' ), '1.3.8', true );
			wp_register_script( 'easing', HEALSOUL_THEME_URI . '/assets/libs/easing/jquery.easing.min.js', array( 'jquery' ), '1.3', true );
			wp_register_script( 'matchheight', HEALSOUL_THEME_URI . '/assets/libs/matchheight/jquery.matchheight-min.js', array( 'jquery' ), HEALSOUL_THEME_VERSION, true );
			wp_register_script( 'gmap3', HEALSOUL_THEME_URI . '/assets/libs/gmap3/gmap3.min.js', array( 'jquery' ), HEALSOUL_THEME_VERSION, true );
			wp_register_script( 'countdown', HEALSOUL_THEME_URI . '/assets/libs/jquery.countdown/js/jquery.countdown.min.js', array( 'jquery' ), HEALSOUL_THEME_VERSION, true );
			wp_register_script( 'typed', HEALSOUL_THEME_URI . '/assets/libs/typed/typed.min.js', array( 'jquery' ), null, true );

			// Fix WordPress old version not registered this script
			if ( ! wp_script_is( 'imagesloaded', 'registered' ) ) {
				wp_register_script( 'imagesloaded', HEALSOUL_THEME_URI . '/assets/libs/imagesloaded/imagesloaded.min.js', array( 'jquery' ), null, true );
			}

			wp_register_script( 'isotope-masonry', HEALSOUL_THEME_URI . '/assets/libs/isotope/js/isotope.pkgd.min.js', array( 'jquery' ), HEALSOUL_THEME_VERSION, true );
			wp_register_script( 'isotope-packery', HEALSOUL_THEME_URI . '/assets/libs/packery-mode/packery-mode.pkgd.min.js', array(
				'jquery',
				'imagesloaded',
				'isotope-masonry',
			),                  HEALSOUL_THEME_VERSION, true );

			wp_register_script( 'smooth-scroll', HEALSOUL_THEME_URI . '/assets/libs/smooth-scroll-for-web/SmoothScroll.min.js', array(
				'jquery',
			),                  '1.4.6', true );

			wp_register_script( 'lazyload', HEALSOUL_THEME_URI . "/assets/libs/lazyload/lazyload.js", array(), HEALSOUL_THEME_VERSION, true );

			wp_register_script( 'odometer', HEALSOUL_THEME_URI . '/assets/libs/odometer/odometer.min.js', array(
				'jquery',
			),                  HEALSOUL_THEME_VERSION, true );

			wp_register_script( 'counter-up', HEALSOUL_THEME_URI . '/assets/libs/countTo/jquery.countTo.js', array(
				'jquery',
			),                  HEALSOUL_THEME_VERSION, true );

			// Counter JS by Healsoul theme
			wp_register_script( 'healsoul-counter', HEALSOUL_THEME_URI . "/assets/js/counter.js", array(
				'jquery',
			),                  HEALSOUL_THEME_VERSION, true );

			wp_register_script( 'chart', HEALSOUL_THEME_URI . '/assets/libs/chart/chart.min.js', array(
				'jquery',
			),                  HEALSOUL_THEME_VERSION, true );

			// Chart JS by Healsoul theme
			wp_register_script( 'healsoul-chart', HEALSOUL_THEME_URI . "/assets/js/chart.js", array(
				'jquery',
				'vc_waypoints',
				'chart',
			),                  HEALSOUL_THEME_VERSION, true );

			wp_register_script( 'circle-progress', HEALSOUL_THEME_URI . '/assets/libs/circle-progress/circle-progress.min.js', array( 'jquery' ), null, true );

			// Circle Progress JS by Healsoul theme
			wp_register_script( 'healsoul-circle-progress', HEALSOUL_THEME_URI . "/assets/js/circle-progress.js", array(
				'jquery',
				'vc_waypoints',
				'circle-progress',
			),                  null, true );

			wp_register_script( 'healsoul-pricing', HEALSOUL_THEME_URI . "/assets/js/pricing.js", array(
				'jquery',
				'matchheight',
			),                  null, true );

			// Accordion JS by Healsoul theme
			wp_register_script( 'healsoul-accordion', HEALSOUL_THEME_URI . "/assets/js/accordion.js", array( 'jquery' ), HEALSOUL_THEME_VERSION, true );

			// Enqueue the theme's style.css

			if ( is_rtl() ) {
				wp_enqueue_style( 'healsoul-style', get_template_directory_uri() . "/style-rtl{$min}.css" );
				wp_enqueue_style( 'healsoul-style-rtl-custom' );
			} else {
				wp_enqueue_style( 'healsoul-style', get_template_directory_uri() . "/style{$min}.css" );
			}

			wp_enqueue_style( 'font-ion' );
			wp_enqueue_style( 'font-icomoon' );
			wp_enqueue_style( 'font-linea' );
			wp_enqueue_style( 'font-awesome' );
			wp_enqueue_style( 'swiper' );
			wp_enqueue_style( 'spinkit' );

			// Register scripts
			if ( Healsoul::setting( 'header_sticky_enable' ) ) {
				wp_enqueue_script( 'headroom', HEALSOUL_THEME_URI . "/assets/js/headroom.js", array( 'jquery' ), HEALSOUL_THEME_VERSION, true );
			}

			if ( Healsoul::setting( 'smooth_scroll_enable' ) ) {
				// Smooth scroll bar
				wp_enqueue_script( 'smooth-scroll' );
			}

			// Smooth scroll link
			wp_enqueue_script( 'jquery-smooth-scroll', HEALSOUL_THEME_URI . '/assets/libs/smooth-scroll/jquery.smooth-scroll.min.js', array( 'jquery' ), HEALSOUL_THEME_VERSION, true );

			wp_enqueue_script( 'swiper' );
			wp_enqueue_script( 'matchheight' );
			wp_enqueue_script( 'vc_waypoints' );
			wp_enqueue_script( 'smartmenus', HEALSOUL_THEME_URI . "/assets/libs/smartmenus/jquery.smartmenus.js", array( 'jquery' ), HEALSOUL_THEME_VERSION, true );

			if ( Healsoul::setting( 'lazy_load_images' ) ) {
				wp_enqueue_script( 'lazyload' );
			}

			// The comment-reply script
			if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
				if ( $post_type === 'post' ) {
					if ( Healsoul::setting( 'single_post_comment_enable' ) === '1' ) {
						wp_enqueue_script( 'comment-reply' );
					}
				} elseif ( $post_type === 'case_study' ) {
					if ( Healsoul::setting( 'single_case_study_comment_enable' ) === '1' ) {
						wp_enqueue_script( 'comment-reply' );
					}
				} elseif ( $post_type === 'service' ) {
					if ( Healsoul::setting( 'single_service_comment_enable' ) === '1' ) {
						wp_enqueue_script( 'comment-reply' );
					}
				} else {
					wp_enqueue_script( 'comment-reply' );
				}
			}

			// Load Visual Composer JS above theme JS
			wp_enqueue_script( 'wpb_composer_front_js' );

			// Enqueue main JS
			wp_enqueue_script( 'healsoul-script', HEALSOUL_THEME_URI . "/assets/js/main.js", array(
				'jquery',
			),                 HEALSOUL_THEME_VERSION, true );

			if ( Healsoul_Helper::active_woocommerce() ) {
				wp_enqueue_script( 'healsoul-woo', HEALSOUL_THEME_URI . "/assets/js/woo.js", array(
					'healsoul-script',
				),                 HEALSOUL_THEME_VERSION, true );
			}

			// Enqueue custom variable JS
			$js_variables = array(
				'isRTL'                     => is_rtl(),
				'templateUrl'               => HEALSOUL_THEME_URI,
				'ajaxurl'                   => admin_url( 'admin-ajax.php' ),
				'primary_color'             => Healsoul::setting( 'primary_color' ),
				'header_sticky_enable'      => Healsoul::setting( 'header_sticky_enable' ),
				'header_sticky_height'      => Healsoul::setting( 'header_sticky_height' ),
				'scroll_top_enable'         => Healsoul::setting( 'scroll_top_enable' ),
				'lazyLoadImages'            => Healsoul::setting( 'lazy_load_images' ),
				'light_gallery_auto_play'   => Healsoul::setting( 'light_gallery_auto_play' ),
				'light_gallery_download'    => Healsoul::setting( 'light_gallery_download' ),
				'light_gallery_full_screen' => Healsoul::setting( 'light_gallery_full_screen' ),
				'light_gallery_zoom'        => Healsoul::setting( 'light_gallery_zoom' ),
				'light_gallery_thumbnail'   => Healsoul::setting( 'light_gallery_thumbnail' ),
				'light_gallery_share'       => Healsoul::setting( 'light_gallery_share' ),
				'mobile_menu_breakpoint'    => Healsoul::setting( 'mobile_menu_breakpoint' ),
				'isSingleProduct'           => is_singular( 'product' ),
				'like'                      => esc_html__( 'Like', 'healsoul' ),
				'unlike'                    => esc_html__( 'Unlike', 'healsoul' ),
			);
			wp_localize_script( 'healsoul-script', '$insight', $js_variables );

			// Custom JS
			if ( Healsoul::setting( 'custom_js_enable' ) == 1 ) {
				wp_add_inline_script( 'healsoul-script', html_entity_decode( Healsoul::setting( 'custom_js' ) ) );
			}
		}

		/**
		 * @return string
		 */
		public function get_min_suffix() {
			return defined( 'SCRIPT_DEBUG' ) && true === SCRIPT_DEBUG ? '' : '.min';
		}
	}

	new Healsoul_Enqueue();
}
