<?php
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Healsoul_Metabox' ) ) {
	class Healsoul_Metabox {

		/**
		 * Healsoul_Metabox constructor.
		 */
		public function __construct() {
			add_filter( 'insight_core_meta_boxes', array( $this, 'register_meta_boxes' ) );
			add_filter( 'healsoul_page_meta_box_presets', array( $this, 'page_meta_box_presets' ) );
		}

		public function page_meta_box_presets( $presets ) {
			$presets[] = 'color_preset';

			return $presets;
		}

		/**
		 * Register Metabox
		 *
		 * @param $meta_boxes
		 *
		 * @return array
		 */
		public function register_meta_boxes( $meta_boxes ) {
			$page_registered_sidebars = Healsoul_Helper::get_registered_sidebars( true );

			$general_options = array(
				array(
					'title'  => esc_html__( 'General', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'site_layout',
							'type'    => 'select',
							'title'   => esc_html__( 'Layout', 'healsoul' ),
							'desc'    => 'When you choose Default, the value in <a href="' . admin_url( 'customize.php' ) . '" target="_blank">Customizer</a> will be used.',
							'options' => array(
								''      => esc_html__( 'Default', 'healsoul' ),
								'boxed' => esc_html__( 'Boxed', 'healsoul' ),
								'wide'  => esc_html__( 'Wide', 'healsoul' ),
							),
							'default' => '',
						),
						array(
							'id'    => 'site_width',
							'type'  => 'text',
							'title' => esc_html__( 'Site Width', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the site width for this page. Enter value including any valid CSS unit, e.g 1200px. Leave blank to use global setting.', 'healsoul' ),
						),
						array(
							'id'      => 'content_padding',
							'type'    => 'switch',
							'title'   => esc_html__( 'Content Padding', 'healsoul' ),
							'desc'    => 'By default, the page content has the padding top & bottom is 100px.',
							'default' => '1',
							'options' => array(
								'1'      => esc_html__( 'Default', 'healsoul' ),
								'0'      => esc_html__( 'No Padding', 'healsoul' ),
								'top'    => esc_html__( 'No Top Padding', 'healsoul' ),
								'bottom' => esc_html__( 'No Bottom Padding', 'healsoul' ),
							),
						),
						array(
							'id'      => 'body_class',
							'type'    => 'text',
							'title'   => esc_html__( 'Body Class', 'healsoul' ),
							'desc'    => esc_html__( 'Add a class name to body and refer to it in custom CSS.', 'healsoul' ),
							'default' => '',
						),
					),
				),
				array(
					'title'  => esc_html__( 'Color', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'color_preset',
							'type'    => 'select',
							'title'   => esc_html__( 'Preset', 'healsoul' ),
							'desc'    => esc_html__( 'Select a preset of color for this page.', 'healsoul' ),
							'options' => array(
								'-1' => esc_html__( 'None', 'healsoul' ),
								'01' => esc_html__( 'Preset 01', 'healsoul' ),
								'02' => esc_html__( 'Preset 02', 'healsoul' ),
								'03' => esc_html__( 'Preset 03', 'healsoul' ),
								'04' => esc_html__( 'Preset 04', 'healsoul' ),
								'05' => esc_html__( 'Preset 05', 'healsoul' ),
								'06' => esc_html__( 'Preset 06', 'healsoul' ),
								'07' => esc_html__( 'Preset 07', 'healsoul' ),
								'08' => esc_html__( 'Preset 08', 'healsoul' ),
							),
							'default' => '-1',
						),
					),
				),
				array(
					'title'  => esc_html__( 'Background', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'site_background_message',
							'type'    => 'message',
							'title'   => esc_html__( 'Info', 'healsoul' ),
							'message' => esc_html__( 'These options controls the background on boxed mode.', 'healsoul' ),
						),
						array(
							'id'    => 'site_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Background Color', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background color of the outer background area in boxed mode of this page.', 'healsoul' ),
						),
						array(
							'id'    => 'site_background_image',
							'type'  => 'media',
							'title' => esc_html__( 'Background Image', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background image of the outer background area in boxed mode of this page.', 'healsoul' ),
						),
						array(
							'id'      => 'site_background_repeat',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Repeat', 'healsoul' ),
							'desc'    => esc_html__( 'Controls the background repeat of the outer background area in boxed mode of this page.', 'healsoul' ),
							'options' => array(
								'no-repeat' => esc_html__( 'No repeat', 'healsoul' ),
								'repeat'    => esc_html__( 'Repeat', 'healsoul' ),
								'repeat-x'  => esc_html__( 'Repeat X', 'healsoul' ),
								'repeat-y'  => esc_html__( 'Repeat Y', 'healsoul' ),
							),
						),
						array(
							'id'      => 'site_background_attachment',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Attachment', 'healsoul' ),
							'desc'    => esc_html__( 'Controls the background attachment of the outer background area in boxed mode of this page.', 'healsoul' ),
							'options' => array(
								''       => esc_html__( 'Default', 'healsoul' ),
								'fixed'  => esc_html__( 'Fixed', 'healsoul' ),
								'scroll' => esc_html__( 'Scroll', 'healsoul' ),
							),
						),
						array(
							'id'    => 'site_background_position',
							'type'  => 'text',
							'title' => esc_html__( 'Background Position', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background position of the outer background area in boxed mode of this page.', 'healsoul' ),
						),
						array(
							'id'    => 'site_background_size',
							'type'  => 'text',
							'title' => esc_html__( 'Background Size', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background size of the outer background area in boxed mode of this page.', 'healsoul' ),
						),
						array(
							'id'      => 'content_background_message',
							'type'    => 'message',
							'title'   => esc_html__( 'Info', 'healsoul' ),
							'message' => esc_html__( 'These options controls the background of main content on this page.', 'healsoul' ),
						),
						array(
							'id'    => 'content_background_color',
							'type'  => 'color',
							'title' => esc_html__( 'Background Color', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background color of main content on this page.', 'healsoul' ),
						),
						array(
							'id'    => 'content_background_image',
							'type'  => 'media',
							'title' => esc_html__( 'Background Image', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background image of main content on this page.', 'healsoul' ),
						),
						array(
							'id'      => 'content_background_repeat',
							'type'    => 'select',
							'title'   => esc_html__( 'Background Repeat', 'healsoul' ),
							'desc'    => esc_html__( 'Controls the background repeat of main content on this page.', 'healsoul' ),
							'options' => array(
								'no-repeat' => esc_html__( 'No repeat', 'healsoul' ),
								'repeat'    => esc_html__( 'Repeat', 'healsoul' ),
								'repeat-x'  => esc_html__( 'Repeat X', 'healsoul' ),
								'repeat-y'  => esc_html__( 'Repeat Y', 'healsoul' ),
							),
						),
						array(
							'id'    => 'content_background_position',
							'type'  => 'text',
							'title' => esc_html__( 'Background Position', 'healsoul' ),
							'desc'  => esc_html__( 'Controls the background position of main content on this page.', 'healsoul' ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Header', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'top_bar_type',
							'type'    => 'select',
							'title'   => esc_html__( 'Top Bar Type', 'healsoul' ),
							'desc'    => 'When you choose Default, the value in <a href="' . admin_url( 'customize.php' ) . '" target="_blank">Customizer</a> will be used.',
							'default' => '',
							'options' => Healsoul_Helper::get_top_bar_list( true ),
						),
						array(
							'id'      => 'header_type',
							'type'    => 'select',
							'title'   => esc_html__( 'Header Type', 'healsoul' ),
							'desc'    => 'When you choose Default, the value in <a href="' . admin_url( 'customize.php' ) . '" target="_blank">Customizer</a> will be used.',
							'default' => '',
							'options' => Healsoul_Helper::get_header_list( true ),
						),
						array(
							'id'      => 'menu_display',
							'type'    => 'select',
							'title'   => esc_html__( 'Primary Menu', 'healsoul' ),
							'desc'    => esc_html__( 'Select which menu displays on this page.', 'healsoul' ),
							'default' => '',
							'options' => Healsoul_Helper::get_all_menus(),
						),
						array(
							'id'      => 'menu_one_page',
							'type'    => 'switch',
							'title'   => esc_html__( 'One Page Menu', 'healsoul' ),
							'default' => '0',
							'options' => array(
								'0' => esc_html__( 'Disable', 'healsoul' ),
								'1' => esc_html__( 'Enable', 'healsoul' ),
							),
						),
						array(
							'id'      => 'custom_logo',
							'type'    => 'media',
							'title'   => esc_html__( 'Custom Logo', 'healsoul' ),
							'desc'    => esc_html__( 'Select custom logo for this page.', 'healsoul' ),
							'default' => '',
						),
						array(
							'id'      => 'custom_logo_retina',
							'type'    => 'media',
							'title'   => esc_html__( 'Custom Logo Retina', 'healsoul' ),
							'desc'    => esc_html__( 'Select custom logo retina for this page.', 'healsoul' ),
							'default' => '',
						),
						array(
							'id'      => 'custom_logo_width',
							'type'    => 'text',
							'title'   => esc_html__( 'Custom Logo Width', 'healsoul' ),
							'desc'    => esc_html__( 'Controls the width of logo, e.g 190px', 'healsoul' ),
							'default' => '',
						),
						array(
							'id'      => 'custom_sticky_logo_width',
							'type'    => 'text',
							'title'   => esc_html__( 'Custom Sticky Logo Width', 'healsoul' ),
							'desc'    => esc_html__( 'Controls the width of sticky logo, e.g 150px', 'healsoul' ),
							'default' => '',
						),
					),
				),
				array(
					'title'  => esc_html__( 'Title', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'page_title_bar_layout',
							'type'    => 'select',
							'title'   => esc_html__( 'Layout', 'healsoul' ),
							'desc'    => 'When you choose Default, the value in <a href="' . admin_url( 'customize.php' ) . '" target="_blank">Customizer</a> will be used.',
							'default' => 'default',
							'options' => Healsoul_Helper::get_title_bar_list( true ),
						),
						array(
							'id'      => 'page_title_bar_background_color',
							'type'    => 'color',
							'title'   => esc_html__( 'Background Color', 'healsoul' ),
							'default' => '',
						),
						array(
							'id'      => 'page_title_bar_background',
							'type'    => 'media',
							'title'   => esc_html__( 'Background Image', 'healsoul' ),
							'default' => '',
						),
						array(
							'id'      => 'page_title_bar_background_overlay',
							'type'    => 'color',
							'title'   => esc_html__( 'Background Overlay', 'healsoul' ),
							'default' => '',
						),
						array(
							'id'    => 'page_title_bar_custom_heading',
							'type'  => 'text',
							'title' => esc_html__( 'Custom Title', 'healsoul' ),
							'desc'  => esc_html__( 'Insert custom heading for the page title bar. Leave blank to use default.', 'healsoul' ),
						),
						array(
							'id'    => 'page_title_bar_custom_text',
							'type'  => 'text',
							'title' => esc_html__( 'Custom text', 'healsoul' ),
							'desc'  => esc_html__( 'Insert custom text for the page title bar. Leave blank to use default.', 'healsoul' ),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Sidebar', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'page_sidebar_position',
							'type'    => 'switch',
							'title'   => esc_html__( 'Position', 'healsoul' ),
							'desc'    => 'When you choose Default, the value in <a href="' . admin_url( 'customize.php' ) . '" target="_blank">Customizer</a> will be used.',
							'default' => 'default',
							'options' => Healsoul_Helper::get_list_sidebar_positions( true ),
						),
						array(
							'id'      => 'page_sidebar_1',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar 1', 'healsoul' ),
							'desc'    => esc_html__( 'Select sidebar 1 that will display on this page.', 'healsoul' ),
							'default' => 'default',
							'options' => $page_registered_sidebars,
						),
						array(
							'id'      => 'page_sidebar_2',
							'type'    => 'select',
							'title'   => esc_html__( 'Sidebar 2', 'healsoul' ),
							'desc'    => esc_html__( 'Select sidebar 2 that will display on this page.', 'healsoul' ),
							'default' => 'default',
							'options' => $page_registered_sidebars,
						),
					),
				),
				array(
					'title'  => esc_html__( 'Slider', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'revolution_slider',
							'type'    => 'select',
							'title'   => esc_html__( 'Revolution Slider', 'healsoul' ),
							'desc'    => esc_html__( 'Select the unique name of the slider.', 'healsoul' ),
							'options' => Healsoul_Helper::get_list_revslider(),
						),
						array(
							'id'      => 'slider_position',
							'type'    => 'select',
							'title'   => esc_html__( 'Position', 'healsoul' ),
							'default' => 'below',
							'options' => array(
								'above' => esc_html__( 'Above Header', 'healsoul' ),
								'below' => esc_html__( 'Below Header', 'healsoul' ),
							),
						),
					),
				),
				array(
					'title'  => esc_html__( 'Footer', 'healsoul' ),
					'fields' => array(
						array(
							'id'      => 'footer_page',
							'type'    => 'select',
							'title'   => esc_html__( 'Footer', 'healsoul' ),
							'desc'    => 'When you choose Default, the value in <a href="' . admin_url( 'customize.php' ) . '" target="_blank">Customizer</a> will be used.',
							'default' => 'default',
							'options' => Healsoul_Footer::get_list_footers( true ),
						),
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_page_options',
				'title'      => esc_html__( 'Page Options', 'healsoul' ),
				'post_types' => array( 'page' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => $general_options,
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_post_options',
				'title'      => esc_html__( 'Page Options', 'healsoul' ),
				'post_types' => array( 'post' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array_merge( array(
							array(
								'title'  => esc_html__( 'Post', 'healsoul' ),
								'fields' => array(
									array(
										'id'    => 'post_gallery',
										'type'  => 'gallery',
										'title' => esc_html__( 'Gallery Format', 'healsoul' ),
									),
									array(
										'id'    => 'post_video',
										'type'  => 'textarea',
										'title' => esc_html__( 'Video Format', 'healsoul' ),
									),
									array(
										'id'    => 'post_audio',
										'type'  => 'textarea',
										'title' => esc_html__( 'Audio Format', 'healsoul' ),
									),
									array(
										'id'    => 'post_quote_text',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Text', 'healsoul' ),
									),
									array(
										'id'    => 'post_quote_name',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Name', 'healsoul' ),
									),
									array(
										'id'    => 'post_quote_url',
										'type'  => 'text',
										'title' => esc_html__( 'Quote Format - Source Url', 'healsoul' ),
									),
									array(
										'id'    => 'post_link',
										'type'  => 'text',
										'title' => esc_html__( 'Link Format', 'healsoul' ),
									),
								),
							),
						), $general_options ),
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_product_options',
				'title'      => esc_html__( 'Page Options', 'healsoul' ),
				'post_types' => array( 'product' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => $general_options,
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_case_study_options',
				'title'      => esc_html__( 'Page Options', 'healsoul' ),
				'post_types' => array( 'case_study' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => $general_options,
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_service_options',
				'title'      => esc_html__( 'Page Options', 'healsoul' ),
				'post_types' => array( 'service' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array_merge( array(
							array(
								'title'  => esc_html__( 'Service', 'healsoul' ),
								'fields' => array(
									array(
										'id'      => 'service_message',
										'type'    => 'message',
										'title'   => esc_html__( 'Info', 'healsoul' ),
										'message' => esc_html__( 'These options just use for the service.', 'healsoul' ),
									),
									array(
										'id'      => 'service_style',
										'type'    => 'select',
										'title'   => esc_html__( 'Style', 'healsoul' ),
										'desc'    => esc_html__( 'Select style for the single service page.', 'healsoul' ),
										'default' => '',
										'options' => array(
											''   => esc_html__( 'Default', 'healsoul' ),
											'01' => esc_html__( 'Style 01', 'healsoul' ),
											'02' => esc_html__( 'Style 02', 'healsoul' ),
										),
									),
									array(
										'id'      => 'service_icon',
										'type'    => 'text',
										'title'   => esc_html__( 'Icon', 'healsoul' ),
										'desc'    => esc_html__( 'Add the icon for this service.', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'service_trending',
										'type'    => 'switch',
										'title'   => esc_html__( 'Trending', 'healsoul' ),
										'default' => '0',
										'options' => array(
											'0'   => esc_html__( 'No', 'healsoul' ),
											'yes' => esc_html__( 'Yes', 'healsoul' ),
										),
									),
								),
							),
						), $general_options ),
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_caregiver_options',
				'title'      => esc_html__( 'Caregiver Options', 'healsoul' ),
				'post_types' => array( 'ic_caregiver' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array_merge( array(
							array(
								'title'  => esc_html__( 'Caregiver Details', 'healsoul' ),
								'fields' => array(
									array(
										'id'      => 'position',
										'type'    => 'text',
										'title'   => esc_html__( 'Position', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a position of caregiver (for example: "Physiotherapist").', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url_facebook',
										'type'    => 'text',
										'title'   => esc_html__( 'Facebook', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL facebook.', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url_twitter',
										'type'    => 'text',
										'title'   => esc_html__( 'Twitter', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL twitter.', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url_instagram',
										'type'    => 'text',
										'title'   => esc_html__( 'Instagram', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL instagram.', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url_google_plus',
										'type'    => 'text',
										'title'   => esc_html__( 'Google plus', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL google plus.', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url_linkedin',
										'type'    => 'text',
										'title'   => esc_html__( 'Linkedin', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL linkedin.', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url_pinterest',
										'type'    => 'text',
										'title'   => esc_html__( 'Pinterest', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL pinterest.', 'healsoul' ),
										'default' => '',
									),

								),
							),
						), $general_options ),
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_testimonial_options',
				'title'      => esc_html__( 'Testimonial Options', 'healsoul' ),
				'post_types' => array( 'testimonial' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array(
							array(
								'title'  => esc_html__( 'Testimonial Details', 'healsoul' ),
								'fields' => array(
									array(
										'id'      => 'by_line',
										'type'    => 'text',
										'title'   => esc_html__( 'By Line', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a byline for the customer giving this testimonial (for example: "CEO of Thememove").', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'url',
										'type'    => 'text',
										'title'   => esc_html__( 'Url', 'healsoul' ),
										'desc'    => esc_html__( 'Enter a URL that applies to this customer (for example: http://www.thememove.com/).', 'healsoul' ),
										'default' => '',
									),
									array(
										'id'      => 'rating',
										'type'    => 'select',
										'title'   => esc_html__( 'Rating', 'healsoul' ),
										'default' => '',
										'options' => array(
											''  => esc_html__( 'Select a rating', 'healsoul' ),
											'1' => esc_html__( '1 Star', 'healsoul' ),
											'2' => esc_html__( '2 Stars', 'healsoul' ),
											'3' => esc_html__( '3 Stars', 'healsoul' ),
											'4' => esc_html__( '4 Stars', 'healsoul' ),
											'5' => esc_html__( '5 Stars', 'healsoul' ),
										),
									),
								),
							),
						),
					),
				),
			);

			$meta_boxes[] = array(
				'id'         => 'insight_footer_options',
				'title'      => esc_html__( 'Footer Options', 'healsoul' ),
				'post_types' => array( 'ic_footer' ),
				'context'    => 'normal',
				'priority'   => 'high',
				'fields'     => array(
					array(
						'type'  => 'tabpanel',
						'items' => array(
							array(
								'title'  => esc_html__( 'Effect', 'healsoul' ),
								'fields' => array(
									array(
										'id'      => 'effect',
										'type'    => 'switch',
										'title'   => esc_html__( 'Effect', 'healsoul' ),
										'default' => '',
										'options' => array(
											''         => esc_html__( 'Normal', 'healsoul' ),
											'parallax' => esc_html__( 'Parallax', 'healsoul' ),
										),
									),
								),
							),
							array(
								'title'  => esc_html__( 'Styling', 'healsoul' ),
								'fields' => array(
									array(
										'id'      => 'style',
										'type'    => 'select',
										'title'   => esc_html__( 'Style', 'healsoul' ),
										'default' => '01',
										'options' => array(
											'01' => esc_html__( 'Style 01', 'healsoul' ),
											'02' => esc_html__( 'Style 02', 'healsoul' ),
										),
									),
								),
							),
						),
					),
				),
			);

			return $meta_boxes;
		}

	}

	new Healsoul_Metabox();
}
