<?php
// Exit if accessed directly.
if ( ! defined( 'ABSPATH' ) ) {
	exit;
}

if ( ! class_exists( 'Healsoul_VC_Icon_Healsoul' ) ) {
	class Healsoul_VC_Icon_Healsoul {

		public function __construct() {
			/*
			 * Add styles & script file only on add new or edit post type.
			 */
			add_action( 'load-post.php', array( $this, 'enqueue_scripts' ) );
			add_action( 'load-post-new.php', array( $this, 'enqueue_scripts' ) );

			add_filter( 'vc_iconpicker-type-healsoul', array( $this, 'add_fonts' ) );
			add_filter( 'healsoul_vc_icon_libraries', array( $this, 'add_to_libraries' ) );
			add_filter( 'healsoul_vc_icon_libraries_fields', array( $this, 'add_icon_picker_field' ), 10, 2 );

			add_action( 'vc_enqueue_font_icon_element', array( $this, 'vc_element_enqueue' ) );
		}

		public function add_to_libraries( $list ) {
			$list = $list + array( esc_html__( 'Healsoul', 'healsoul' ) => 'healsoul' );

			return $list;
		}

		public function add_icon_picker_field( $fields, $args ) {
			$fields[] = array(
				'type'        => 'iconpicker',
				'heading'     => esc_html__( 'Icon', 'healsoul' ),
				'param_name'  => 'icon_healsoul',
				'value'       => 'healsoul-brain',
				'settings'    => array(
					'emptyIcon'    => true,
					'type'         => 'healsoul',
					'iconsPerPage' => 400,
				),
				'dependency'  => array(
					'element' => $args['param_name'],
					'value'   => 'healsoul',
				),
				'description' => esc_html__( 'Select icon from library.', 'healsoul' ),
			);

			return $fields;
		}


		public function vc_element_enqueue( $font ) {
			switch ( $font ) {
				case 'healsoul':
					wp_enqueue_style( 'font-healsoul', HEALSOUL_THEME_URI . '/assets/fonts/healsoul/font-healsoul.css', null, null );
					break;
			}
		}

		public function enqueue_scripts() {
			add_action( 'admin_enqueue_scripts', array( $this, 'admin_enqueue_scripts' ) );
		}

		function admin_enqueue_scripts() {
			wp_enqueue_style( 'font-healsoul', HEALSOUL_THEME_URI . '/assets/fonts/healsoul/font-healsoul.css', null, null );
		}

		public function add_fonts( $icons ) {
			$new_icons = array(
				array( 'healsoul-brain' => 'brain' ),
				array( 'healsoul-circular-plus-button' => 'circular-plus-button' ),
				array( 'healsoul-eyeglasses' => 'eyeglasses' ),
				array( 'healsoul-smiling-baby' => 'smiling-baby' ),
				array( 'healsoul-stethoscope' => 'stethoscope' ),
				array( 'healsoul-tooth' => 'tooth' ),
				array( 'healsoul-woman' => 'woman' ),
			);

			return array_merge( $icons, $new_icons );
		}
	}

	new Healsoul_VC_Icon_Healsoul();
}
