<?php

add_filter( 'vc_autocomplete_tm_case_study_taxonomies_callback', array(
	'WPBakeryShortCode_TM_Case_Study',
	'autocomplete_taxonomies_field_search',
), 10, 1 );

add_filter( 'vc_autocomplete_tm_case_study_taxonomies_render', array(
	Healsoul_VC::instance(),
	'autocomplete_taxonomies_field_render',
), 10, 1 );

add_filter( 'vc_autocomplete_tm_case_study_filter_by_callback', array(
	'WPBakeryShortCode_TM_Case_Study',
	'autocomplete_taxonomies_field_search',
), 10, 1 );

add_filter( 'vc_autocomplete_tm_case_study_filter_by_render', array(
	Healsoul_VC::instance(),
	'autocomplete_taxonomies_field_render',
), 10, 1 );

class WPBakeryShortCode_TM_Case_Study extends WPBakeryShortCode {

	/**
	 * @param $search_string
	 *
	 * @return array|bool
	 */
	public static function autocomplete_taxonomies_field_search( $search_string ) {
		$data = Healsoul_VC::instance()->autocomplete_get_data_from_post_type( $search_string, 'case_study' );

		return $data;
	}

	public function get_inline_css( $selector, $atts ) {
		Healsoul_VC::get_grid_css( $selector, $atts );

		Healsoul_VC::get_vc_spacing_css( $selector, $atts );
	}
}

$grid_arr = array(
	'grid',
	'grid-caption',
	'grid-caption-2',
	'grid-caption-3',
);

vc_map( array(
	'name'     => esc_html__( 'Resource', 'healsoul' ),
	'base'     => 'tm_case_study',
	'category' => HEALSOUL_VC_SHORTCODE_CATEGORY,
	'icon'     => 'insight-i insight-i-grid',
	'params'   => array_merge( array(
		array(
			'heading'     => esc_html__( 'Style', 'healsoul' ),
			'type'        => 'dropdown',
			'param_name'  => 'style',
			'admin_label' => true,
			'value'       => array(
				esc_html__( 'Grid', 'healsoul' )           => 'grid',
				esc_html__( 'Grid Caption 1', 'healsoul' ) => 'grid-caption',
				esc_html__( 'Grid Caption 2', 'healsoul' ) => 'grid-caption-2',
				esc_html__( 'Grid Caption 3', 'healsoul' ) => 'grid-caption-3',
			),
			'std'         => 'grid-caption-3',
		),

		array(
			'heading'     => esc_html__( 'Columns', 'healsoul' ),
			'type'        => 'number_responsive',
			'param_name'  => 'columns',
			'min'         => 1,
			'max'         => 6,
			'step'        => 1,
			'suffix'      => '',
			'media_query' => array(
				'lg' => '3',
				'md' => '',
				'sm' => '2',
				'xs' => '1',
			),
			'dependency'  => array(
				'element' => 'style',
				'value'   => $grid_arr,
			),
		),
		array(
			'heading'     => esc_html__( 'Columns Gutter', 'healsoul' ),
			'description' => esc_html__( 'Controls the gutter of grid columns.', 'healsoul' ),
			'type'        => 'number',
			'param_name'  => 'gutter',
			'std'         => 30,
			'min'         => 0,
			'max'         => 100,
			'step'        => 1,
			'suffix'      => 'px',
			'dependency'  => array(
				'element' => 'style',
				'value'   => $grid_arr,
			),
		),
		array(
			'heading'     => esc_html__( 'Rows Gutter', 'healsoul' ),
			'description' => esc_html__( 'Controls the gutter of grid rows.', 'healsoul' ),
			'type'        => 'number',
			'param_name'  => 'row_gutter',
			'std'         => 30,
			'min'         => 0,
			'max'         => 100,
			'step'        => 1,
			'suffix'      => 'px',
			'dependency'  => array(
				'element' => 'style',
				'value'   => $grid_arr,
			),
		),
		array(
			'heading'    => esc_html__( 'Image Size', 'healsoul' ),
			'type'       => 'dropdown',
			'param_name' => 'image_size',
			'value'      => array(
				esc_html__( '370x243', 'healsoul' )  => '370x243',
				esc_html__( '370x320', 'healsoul' )  => '370x320',
				esc_html__( '480x480', 'healsoul' )  => '480x480',
				esc_html__( '570x385', 'healsoul' )  => '570x385',
			),
			'std'        => '370x243',
		),
		Healsoul_VC::get_animation_field( array(
			'std'        => 'move-up',
			'dependency' => array(
				'element' => 'style',
				'value'   => $grid_arr,
			),
		) ),
		Healsoul_VC::extra_class_field(),
		array(
			'group'      => esc_html__( 'Data Settings', 'healsoul' ),
			'type'       => 'hidden',
			'param_name' => 'main_query',
			'std'        => '',
		),
		array(
			'group'       => esc_html__( 'Data Settings', 'healsoul' ),
			'heading'     => esc_html__( 'Items per page', 'healsoul' ),
			'description' => esc_html__( 'Number of items to show per page.', 'healsoul' ),
			'type'        => 'number',
			'param_name'  => 'number',
			'std'         => 9,
			'min'         => 1,
			'max'         => 100,
			'step'        => 1,
		),
		array(
			'group'              => esc_html__( 'Data Settings', 'healsoul' ),
			'heading'            => esc_html__( 'Narrow data source', 'healsoul' ),
			'description'        => esc_html__( 'Enter categories, tags or custom taxonomies.', 'healsoul' ),
			'type'               => 'autocomplete',
			'param_name'         => 'taxonomies',
			'settings'           => array(
				'multiple'       => true,
				'min_length'     => 1,
				'groups'         => true,
				// In UI show results grouped by groups, default false.
				'unique_values'  => true,
				// In UI show results except selected. NB! You should manually check values in backend, default false.
				'display_inline' => true,
				// In UI show results inline view, default false (each value in own line).
				'delay'          => 500,
				// delay for search. default 500.
				'auto_focus'     => true,
				// auto focus input, default true.
			),
			'param_holder_class' => 'vc_not-for-custom',
		),
		array(
			'group'       => esc_html__( 'Data Settings', 'healsoul' ),
			'heading'     => esc_html__( 'Order by', 'healsoul' ),
			'type'        => 'dropdown',
			'param_name'  => 'orderby',
			'value'       => array(
				esc_html__( 'Date', 'healsoul' )                  => 'date',
				esc_html__( 'Post ID', 'healsoul' )               => 'ID',
				esc_html__( 'Author', 'healsoul' )                => 'author',
				esc_html__( 'Title', 'healsoul' )                 => 'title',
				esc_html__( 'Last modified date', 'healsoul' )    => 'modified',
				esc_html__( 'Post/page parent ID', 'healsoul' )   => 'parent',
				esc_html__( 'Number of comments', 'healsoul' )    => 'comment_count',
				esc_html__( 'Menu order/Page Order', 'healsoul' ) => 'menu_order',
				esc_html__( 'Meta value', 'healsoul' )            => 'meta_value',
				esc_html__( 'Meta value number', 'healsoul' )     => 'meta_value_num',
				esc_html__( 'Random order', 'healsoul' )          => 'rand',
			),
			'description' => esc_html__( 'Select order type. If "Meta value" or "Meta value Number" is chosen then meta key is required.', 'healsoul' ),
			'std'         => 'date',
		),
		array(
			'group'       => esc_html__( 'Data Settings', 'healsoul' ),
			'heading'     => esc_html__( 'Sort order', 'healsoul' ),
			'type'        => 'dropdown',
			'param_name'  => 'order',
			'value'       => array(
				esc_html__( 'Descending', 'healsoul' ) => 'DESC',
				esc_html__( 'Ascending', 'healsoul' )  => 'ASC',
			),
			'description' => esc_html__( 'Select sorting order.', 'healsoul' ),
			'std'         => 'DESC',
		),
		array(
			'group'       => esc_html__( 'Data Settings', 'healsoul' ),
			'heading'     => esc_html__( 'Meta key', 'healsoul' ),
			'description' => esc_html__( 'Input meta key for grid ordering.', 'healsoul' ),
			'type'        => 'textfield',
			'param_name'  => 'meta_key',
			'dependency'  => array(
				'element' => 'orderby',
				'value'   => array(
					'meta_value',
					'meta_value_num',
				),
			),
		),
	), Healsoul_VC::get_grid_filter_fields(), Healsoul_VC::get_grid_pagination_fields(), Healsoul_VC::get_vc_spacing_tab(), Healsoul_VC::get_custom_style_tab() ),
) );
