<?php

class WPBakeryShortCode_TM_Popup_Video extends WPBakeryShortCode {

	public function get_inline_css( $selector, $atts ) {
		global $healsoul_shortcode_lg_css;
		Healsoul_VC::get_vc_spacing_css( $selector, $atts );
		if ( $atts['bg_image'] !== '' ) {
			$healsoul_shortcode_lg_css .= "$selector .video-play {background-image: url(" . wp_get_attachment_image_url( $atts['bg_image'], 'full' ) . ")};";
		}
	}
}

$posters_style = array(
	'poster-01',
	'poster-02',
	'poster-03',
	'poster-04',
	'poster-05',
	'poster-06',
	'poster-07',
);

$button_style = array(
	'button',
	'button-02',
	'button-03',
	'button-04',
	'button-05',
	'button-06',
);

vc_map( array(
	'name'                      => esc_html__( 'Popup Video', 'healsoul' ),
	'base'                      => 'tm_popup_video',
	'category'                  => HEALSOUL_VC_SHORTCODE_CATEGORY,
	'icon'                      => 'insight-i insight-i-video',
	'allowed_container_element' => 'vc_row',
	'params'                    => array_merge( array(
		array(
			'heading'     => esc_html__( 'Style', 'healsoul' ),
			'type'        => 'dropdown',
			'param_name'  => 'style',
			'admin_label' => true,
			'value'       => array(
				esc_html__( 'Poster Style 01', 'healsoul' ) => 'poster-01',
				esc_html__( 'Poster Style 02', 'healsoul' ) => 'poster-02',
				esc_html__( 'Poster Style 03', 'healsoul' ) => 'poster-03',
				esc_html__( 'Poster Style 04', 'healsoul' ) => 'poster-04',
				esc_html__( 'Poster Style 05', 'healsoul' ) => 'poster-05',
				esc_html__( 'Poster Style 06', 'healsoul' ) => 'poster-06',
				esc_html__( 'Poster Style 07', 'healsoul' ) => 'poster-07',
				esc_html__( 'Button Style 01', 'healsoul' ) => 'button',
				esc_html__( 'Button Style 02', 'healsoul' ) => 'button-02',
				esc_html__( 'Button Style 03', 'healsoul' ) => 'button-03',
				esc_html__( 'Button Style 04', 'healsoul' ) => 'button-04',
				esc_html__( 'Button Style 05', 'healsoul' ) => 'button-05',
				esc_html__( 'Button Style 06', 'healsoul' ) => 'button-06',
			),
			'std'         => 'poster-01',
		),
		array(
			'heading'     => esc_html__( 'Video Url', 'healsoul' ),
			'description' => esc_html__( 'E.g "https://www.youtube.com/watch?v=9No-FiEInLA"', 'healsoul' ),
			'type'        => 'textfield',
			'param_name'  => 'video',
		),
		array(
			'heading'    => esc_html__( 'Video Text', 'healsoul' ),
			'type'       => 'textfield',
			'param_name' => 'video_text',
			'std'        => esc_html__( 'Play Video', 'healsoul' ),
			'dependency' => array(
				'element'            => 'style',
				'value_not_equal_to' => array(
					'poster-02',
					'poster-07',
				),
			),
		),
		array(
			'heading'    => esc_html__( 'Button Background Image', 'healsoul' ),
			'type'       => 'attach_image',
			'param_name' => 'bg_image',
			'dependency' => array( 'element' => 'style', 'value' => array( 'button-06' ) ),
		),
		array(
			'heading'    => esc_html__( 'Align', 'healsoul' ),
			'type'       => 'dropdown',
			'param_name' => 'align',
			'value'      => array(
				esc_html__( 'Left', 'healsoul' )   => 'left',
				esc_html__( 'Center', 'healsoul' ) => 'center',
				esc_html__( 'Right', 'healsoul' )  => 'right',
			),
			'std'        => 'center',
			'dependency' => array( 'element' => 'style', 'value' => $button_style ),
		),
		array(
			'heading'    => esc_html__( 'Poster Image', 'healsoul' ),
			'type'       => 'attach_image',
			'param_name' => 'poster',
			'dependency' => array( 'element' => 'style', 'value' => $posters_style ),
		),
		array(
			'heading'     => esc_html__( 'Poster Image Size', 'healsoul' ),
			'description' => esc_html__( 'Controls the size of poster image.', 'healsoul' ),
			'type'        => 'dropdown',
			'param_name'  => 'image_size',
			'value'       => array(
				esc_html__( '670x455', 'healsoul' ) => '670x455',
				esc_html__( '600x420', 'healsoul' ) => '600x420',
				esc_html__( '570x364', 'healsoul' ) => '570x364',
				esc_html__( '470x320', 'healsoul' ) => '470x320',
				esc_html__( 'Full', 'healsoul' )    => 'full',
				esc_html__( 'Custom', 'healsoul' )  => 'custom',
			),
			'std'         => '670x455',
			'dependency'  => array( 'element' => 'style', 'value' => $posters_style ),
		),
		array(
			'heading'          => esc_html__( 'Image Width', 'healsoul' ),
			'type'             => 'number',
			'param_name'       => 'image_size_width',
			'min'              => 0,
			'max'              => 1920,
			'step'             => 10,
			'suffix'           => 'px',
			'dependency'       => array(
				'element' => 'image_size',
				'value'   => array( 'custom' ),
			),
			'edit_field_class' => 'vc_col-sm-6 col-break',
		),
		array(
			'heading'          => esc_html__( 'Image Height', 'healsoul' ),
			'type'             => 'number',
			'param_name'       => 'image_size_height',
			'min'              => 0,
			'max'              => 1920,
			'step'             => 10,
			'suffix'           => 'px',
			'dependency'       => array(
				'element' => 'image_size',
				'value'   => array( 'custom' ),
			),
			'edit_field_class' => 'vc_col-sm-6 col-break',
		),
		Healsoul_VC::extra_class_field(),
	), Healsoul_VC::get_vc_spacing_tab(), Healsoul_VC::get_custom_style_tab() ),
) );
